==> 0.1.2.tar.gz: lib/widget/vgk-app-bar/vgk-app-bar.dart <==
import 'package:flutter/material.dart';
import 'package:launch_review/launch_review.dart';
import 'package:share/share.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

Widget vgkappBar(String title, double size, String appId, String description) {
  return SizedBox(
    height: AppBar().preferredSize.height,
    child: Container(
      decoration: BoxDecoration(color: VgkprogamingTheme.background),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Expanded(
            child: Center(
              child: Padding(
                padding: const EdgeInsets.only(top: 4, left: 60),
                child: Text(
                  title,
                  style:
                      size >= 375 ? VgkprogamingTheme.h1 : VgkprogamingTheme.h3,
                ),
              ),
            ),
          ),
          Container(
            width: AppBar().preferredSize.height + 40,
            height: AppBar().preferredSize.height,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.end,
              children: <Widget>[
                Material(
                  color: Colors.transparent,
                  child: InkWell(
                    borderRadius: const BorderRadius.all(
                      Radius.circular(32.0),
                    ),
                    onTap: () {
                      LaunchReview.launch(
                        androidAppId: appId,
                      );
                    },
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.rate_review,
                        color: VgkprogamingTheme.primaryColor,
                      ),
                    ),
                  ),
                ),
                Material(
                  color: Colors.transparent,
                  child: InkWell(
                    borderRadius: const BorderRadius.all(
                      Radius.circular(32.0),
                    ),
                    onTap: () {
                      Share.share(description);
                    },
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.share,
                        color: VgkprogamingTheme.primaryColor,
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    ),
  );
}

==> 0.1.4.tar.gz: lib/widget/vgk-app-bar/vgk-app-bar.dart <==
import 'package:flutter/material.dart';
import 'package:launch_review/launch_review.dart';
import 'package:share/share.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

Widget vgkappBar(String title, double size, String appId, String description) {
  return SizedBox(
    height: AppBar().preferredSize.height,
    child: Container(
      decoration: BoxDecoration(color: VgkprogamingTheme.white),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Expanded(
            child: Center(
              child: Padding(
                padding: const EdgeInsets.only(top: 4, left: 60),
                child: Text(
                  title,
                  style:
                      size >= 375 ? VgkprogamingTheme.h1 : VgkprogamingTheme.h3,
                ),
              ),
            ),
          ),
          Container(
            width: AppBar().preferredSize.height + 40,
            height: AppBar().preferredSize.height,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.end,
              children: <Widget>[
                Material(
                  color: Colors.white,
                  child: InkWell(
                    borderRadius: const BorderRadius.all(
                      Radius.circular(32.0),
                    ),
                    onTap: () {
                      LaunchReview.launch(
                        androidAppId: appId,
                      );
                    },
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.rate_review,
                        color: VgkprogamingTheme.primaryColor,
                      ),
                    ),
                  ),
                ),
                Material(
                  color: Colors.transparent,
                  child: InkWell(
                    borderRadius: const BorderRadius.all(
                      Radius.circular(32.0),
                    ),
                    onTap: () {
                      Share.share(description);
                    },
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.share,
                        color: VgkprogamingTheme.primaryColor,
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    ),
  );
}
